@@ -1,8 +1,6 @@
 # Copyright 1999-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
-from __future__ import print_function
-
 import argparse
 import locale
 import platform
@@ -1239,10 +1237,10 @@ def emerge_main(args=None):
 	if myaction == "help":
 		emerge_help()
 		return os.EX_OK
-	elif myaction == "moo":
+	if myaction == "moo":
 		print(COWSAY_MOO % platform.system())
 		return os.EX_OK
-	elif myaction == "sync":
+	if myaction == "sync":
 		# need to set this to True now in order for the repository config
 		# loading to allow new repos with non-existent directories
 		portage._sync_mode = True
