@@ -8,8 +8,6 @@ __all__ = (
 	"Display", "format_unmatched_atom",
 	)
 
-
-import portage
 from portage import os
 from portage.dbapi.dep_expand import dep_expand
 from portage.dep import Atom, cpvequal, _repo_separator, _slot_separator
@@ -245,7 +243,6 @@ class Display:
 				cur_use_map[key], old_iuse_map[key],
 				old_use_map[key], is_new, feature_flags,
 				reinst_flags_map.get(key))
-		return
 
 
 	@staticmethod
@@ -260,26 +257,24 @@ class Display:
 			if pkg_info.built:
 				if pkg_info.system:
 					return colorize("PKG_BINARY_MERGE_SYSTEM", pkg_str)
-				elif pkg_info.world:
+				if pkg_info.world:
 					return colorize("PKG_BINARY_MERGE_WORLD", pkg_str)
-				else:
-					return colorize("PKG_BINARY_MERGE", pkg_str)
-			else:
-				if pkg_info.system:
-					return colorize("PKG_MERGE_SYSTEM", pkg_str)
-				elif pkg_info.world:
-					return colorize("PKG_MERGE_WORLD", pkg_str)
-				else:
-					return colorize("PKG_MERGE", pkg_str)
-		elif pkg_info.operation == "uninstall":
-			return colorize("PKG_UNINSTALL", pkg_str)
-		else:
+				return colorize("PKG_BINARY_MERGE", pkg_str)
+
 			if pkg_info.system:
-				return colorize("PKG_NOMERGE_SYSTEM", pkg_str)
-			elif pkg_info.world:
-				return colorize("PKG_NOMERGE_WORLD", pkg_str)
-			else:
-				return colorize("PKG_NOMERGE", pkg_str)
+				return colorize("PKG_MERGE_SYSTEM", pkg_str)
+			if pkg_info.world:
+				return colorize("PKG_MERGE_WORLD", pkg_str)
+			return colorize("PKG_MERGE", pkg_str)
+
+		if pkg_info.operation == "uninstall":
+			return colorize("PKG_UNINSTALL", pkg_str)
+
+		if pkg_info.system:
+			return colorize("PKG_NOMERGE_SYSTEM", pkg_str)
+		if pkg_info.world:
+			return colorize("PKG_NOMERGE_WORLD", pkg_str)
+		return colorize("PKG_NOMERGE", pkg_str)
 
 
 	def verbose_size(self, pkg, repoadd_set, pkg_info):
@@ -543,7 +538,6 @@ class Display:
 			if show_repos and repoadd:
 				myprint += " " + teal("[%s]" % repoadd)
 			writemsg_stdout("%s\n" % (myprint,), noiselevel=-1)
-		return
 
 
 	def print_blockers(self):
@@ -552,7 +546,6 @@ class Display:
 		"""
 		for pkg in self.blockers:
 			writemsg_stdout("%s\n" % (pkg,), noiselevel=-1)
-		return
 
 
 	def print_verbose(self, show_repos):
@@ -566,7 +559,6 @@ class Display:
 			# that RepoDisplay.__unicode__() is called in python2.
 			writemsg_stdout("%s" % (self.conf.repo_display,),
 				noiselevel=-1)
-		return
 
 
 	def print_changelog(self):
@@ -691,7 +683,6 @@ class Display:
 			if ebuild_path_cl is not None:
 				self.changelogs.extend(_calc_changelog(
 					ebuild_path_cl, pkg_info.previous_pkg, pkg.cpv))
-		return
 
 
 	def check_system_world(self, pkg):
