@@ -1,4 +1,4 @@
-# Copyright: 2005-2019 Gentoo Authors
+# Copyright: 2005-2020 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 # Author(s): Brian Harring (ferringb@gentoo.org)
 
@@ -212,7 +212,7 @@ class ProtectedDict(MutableMapping):
 				self.blacklist[key] = True
 				return
 		raise KeyError(key)
-			
+
 
 	def __iter__(self):
 		for k in self.new:
@@ -242,7 +242,7 @@ class LazyLoad(Mapping):
 	def __getitem__(self, key):
 		if key in self.d:
 			return self.d[key]
-		elif self.pull != None:
+		if self.pull != None:
 			self.d.update(self.pull())
 			self.pull = None
 		return self.d[key]
@@ -256,7 +256,7 @@ class LazyLoad(Mapping):
 	def __contains__(self, key):
 		if key in self.d:
 			return True
-		elif self.pull != None:
+		if self.pull != None:
 			self.d.update(self.pull())
 			self.pull = None
 		return key in self.d
