@@ -2,11 +2,9 @@
 # Distributed under the terms of the GNU General Public License v2
 
 import functools
-import platform
 import shutil
 import socket
 import struct
-import sys
 import tempfile
 import time
 
@@ -51,7 +49,7 @@ class _Handler(BaseHTTPRequestHandler):
 		pass
 
 
-class AsyncHTTPServer(object):
+class AsyncHTTPServer:
 	def __init__(self, host, content, loop):
 		self._host = host
 		self._content = content
