@@ -182,7 +182,7 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env,
 		oldld = None
 
 	newld = specials["LDPATH"]
-	if (oldld != newld):
+	if oldld != newld:
 		#ld.so.conf needs updating and ldconfig needs to be run
 		myfd = atomic_ofstream(ldsoconf_path)
 		myfd.write("# ld.so.conf autogenerated by env-update; make all changes to\n")
@@ -213,7 +213,7 @@ def _env_update(makelinks, target_root, prev_mtimes, contents, env,
 		newprelink.write("# contents of /etc/env.d directory\n")
 
 		for x in sorted(potential_lib_dirs) + ['bin', 'sbin']:
-			newprelink.write('-l /%s\n' % (x,));
+			newprelink.write('-l /%s\n' % (x,))
 		prelink_paths = set()
 		prelink_paths |= set(specials.get('LDPATH', []))
 		prelink_paths |= set(specials.get('PATH', []))
